@@ -16,7 +16,7 @@
 #
 #  partly based on work by Nokia Solutions and Networks Oyj
 """A parallel executor for Robot Framework test cases.
-Version 2.1.0
+Version 2.2.0
 
 Supports all Robot Framework command line options and also following
 options (these must be before normal RF options):
@@ -228,7 +228,7 @@ def execute_and_wait_with(item):
 
 def _create_command_for_execution(caller_id, datasources, is_last, item, outs_dir):
     options = item.options.copy()
-    if item.command == ['robot'] and not options["listener"]:
+    if item.command == ["robot"] and not options["listener"]:
         options["listener"] = ["RobotStackTracer"]
     cmd = (
         item.command
@@ -1069,6 +1069,8 @@ def generate_suite_names(
 
 def generate_suite_names_with_builder(outs_dir, datasources, options):
     opts = _options_for_dryrun(options, outs_dir)
+    if "pythonpath" in opts:
+        del opts["pythonpath"]
     settings = RobotSettings(opts)
     builder = TestSuiteBuilder(
         settings["SuiteNames"], settings.extension, rpa=settings.rpa
@@ -1170,6 +1172,17 @@ def _options_for_rebot(options, start_time_string, end_time_string):
     rebot_options["include"] = []
     if ROBOT_VERSION >= "2.8":
         options["monitormarkers"] = "off"
+    for key in [
+        "skip",
+        "skiponfailure",
+        "variable",
+        "variablefile",
+        "listener",
+        "prerunmodifier",
+        "monitorcolors",
+    ]:
+        if key in rebot_options:
+            del rebot_options[key]
     return rebot_options
 
 
@@ -1265,6 +1278,8 @@ def _copy_output_artifacts(options, file_extensions=None, include_subfolders=Fal
 
 
 def _report_results(outs_dir, pabot_args, options, start_time_string, tests_root_name):
+    if "pythonpath" in options:
+        del options["pythonpath"]
     if ROBOT_VERSION < "4.0":
         stats = {
             "critical": {"total": 0, "passed": 0, "failed": 0},
