@@ -26,17 +26,18 @@ import threading
 import traceback
 
 if sys.version_info < (3,):
+    from collections import Mapping
+
     from SimpleXMLRPCServer import SimpleXMLRPCServer
     from StringIO import StringIO
     from xmlrpclib import Binary, ServerProxy
-    from collections import Mapping
 
     PY2, PY3 = True, False
 else:
+    from collections.abc import Mapping
     from io import StringIO
     from xmlrpc.client import Binary, ServerProxy
     from xmlrpc.server import SimpleXMLRPCServer
-    from collections.abc import Mapping
 
     PY2, PY3 = False, True
     unicode = str
@@ -325,7 +326,7 @@ class StaticRemoteLibrary(object):
         if __name__ == "__init__":
             return []
         kw = self._get_keyword(name)
-        args, varargs, kwargs, defaults = inspect.getargspec(kw)
+        args, varargs, kwargs, defaults = inspect.getfullargspec(kw)
         if inspect.ismethod(kw):
             args = args[1:]  # drop 'self'
         if defaults:
@@ -385,7 +386,7 @@ class DynamicRemoteLibrary(HybridRemoteLibrary):
         self._get_keyword_tags = dynamic_method(library, "get_keyword_tags")
 
     def _get_kwargs_support(self, run_keyword):
-        spec = inspect.getargspec(run_keyword)
+        spec = inspect.getfullargspec(run_keyword)
         return len(spec.args) > 3  # self, name, args, kwargs=None
 
     def run_keyword(self, name, args, kwargs=None):
